[asterisk-commits] jpeeler: branch jpeeler/chan_dahdi r117982 - in /team/jpeeler/chan_dahdi: ./ ...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Thu May 22 15:51:04 CDT 2008


Author: jpeeler
Date: Thu May 22 15:51:04 2008
New Revision: 117982

URL: http://svn.digium.com/view/asterisk?view=rev&rev=117982
Log:
replaced references to zapata.conf with dahdi.conf, plus a few other zaptel strings

Modified:
    team/jpeeler/chan_dahdi/README
    team/jpeeler/chan_dahdi/apps/app_getcpeid.c
    team/jpeeler/chan_dahdi/channels/chan_dahdi.c
    team/jpeeler/chan_dahdi/configs/extensions.ael.sample
    team/jpeeler/chan_dahdi/configs/extensions.conf.sample
    team/jpeeler/chan_dahdi/configs/sla.conf.sample
    team/jpeeler/chan_dahdi/configs/smdi.conf.sample
    team/jpeeler/chan_dahdi/configs/vpb.conf.sample
    team/jpeeler/chan_dahdi/configs/zapata.conf.sample
    team/jpeeler/chan_dahdi/contrib/scripts/autosupport
    team/jpeeler/chan_dahdi/doc/ss7.txt
    team/jpeeler/chan_dahdi/doc/tex/ael.tex
    team/jpeeler/chan_dahdi/doc/tex/configuration.tex
    team/jpeeler/chan_dahdi/doc/tex/sla.tex
    team/jpeeler/chan_dahdi/include/asterisk/doxyref.h

Modified: team/jpeeler/chan_dahdi/README
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/README?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/README (original)
+++ team/jpeeler/chan_dahdi/README Thu May 22 15:51:04 2008
@@ -175,7 +175,7 @@
 understand, and do not affect how it is actually parsed.
 
   Entries of the form 'variable=value' set the value of some parameter in
-asterisk.  For example, in zapata.conf, one might specify:
+asterisk.  For example, in dahdi.conf, one might specify:
 
 	switchtype=national
 

Modified: team/jpeeler/chan_dahdi/apps/app_getcpeid.c
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/apps/app_getcpeid.c?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/apps/app_getcpeid.c (original)
+++ team/jpeeler/chan_dahdi/apps/app_getcpeid.c Thu May 22 15:51:04 2008
@@ -42,7 +42,7 @@
 
 static char *descrip =
 "  GetCPEID(): Obtains and displays ADSI CPE ID and other information in order\n"
-"to properly setup zapata.conf for on-hook operations.\n";
+"to properly setup dahdi.conf for on-hook operations.\n";
 
 
 static int cpeid_setstatus(struct ast_channel *chan, char *stuff[], int voice)

Modified: team/jpeeler/chan_dahdi/channels/chan_dahdi.c
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/channels/chan_dahdi.c?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/configs/extensions.ael.sample (original)
+++ team/jpeeler/chan_dahdi/configs/extensions.ael.sample Thu May 22 15:51:04 2008
@@ -27,7 +27,7 @@
 	TRUNK="Zap/G2";					// Trunk interface
 	//
 	// Note the 'G2' in the TRUNK variable above. It specifies which group (defined
-	// in zapata.conf) to dial, i.e. group 2, and how to choose a channel to use in
+	// in dahdi.conf) to dial, i.e. group 2, and how to choose a channel to use in
 	// the specified group. The four possible options are:
 	//
 	// g: select the lowest-numbered non-busy Zap channel

Modified: team/jpeeler/chan_dahdi/configs/extensions.conf.sample
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/configs/extensions.conf.sample?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/configs/extensions.conf.sample (original)
+++ team/jpeeler/chan_dahdi/configs/extensions.conf.sample Thu May 22 15:51:04 2008
@@ -123,7 +123,7 @@
 TRUNK=Zap/G2					; Trunk interface
 ;
 ; Note the 'G2' in the TRUNK variable above. It specifies which group (defined
-; in zapata.conf) to dial, i.e. group 2, and how to choose a channel to use in
+; in dahdi.conf) to dial, i.e. group 2, and how to choose a channel to use in
 ; the specified group. The four possible options are:
 ;
 ; g: select the lowest-numbered non-busy Zap channel

Modified: team/jpeeler/chan_dahdi/configs/sla.conf.sample
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/configs/sla.conf.sample?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/configs/sla.conf.sample (original)
+++ team/jpeeler/chan_dahdi/configs/sla.conf.sample Thu May 22 15:51:04 2008
@@ -29,7 +29,7 @@
 
 ;autocontext=line1          ; This supports automatic generation of the dialplan entries 
                             ; if the autocontext option is used.  Each trunk should have 
-                            ; a unique context name.  Then, in zapata.conf, this device 
+                            ; a unique context name.  Then, in dahdi.conf, this device 
                             ; should be configured to have incoming calls go to this context.
 
 ;ringtimeout=30             ; Set how long to allow this trunk to ring on an inbound call before hanging 

Modified: team/jpeeler/chan_dahdi/configs/smdi.conf.sample
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/configs/smdi.conf.sample?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/configs/smdi.conf.sample (original)
+++ team/jpeeler/chan_dahdi/configs/smdi.conf.sample Thu May 22 15:51:04 2008
@@ -2,7 +2,7 @@
 
 [interfaces]
 ; Specify serial ports to listen for SMDI messages on below.  These will be
-; referenced later in zapata.conf.  If you do not specify any interfaces then
+; referenced later in dahdi.conf.  If you do not specify any interfaces then
 ; SMDI will be disabled.  Interfaces can have several different attributes
 ; associated with them.
 

Modified: team/jpeeler/chan_dahdi/configs/vpb.conf.sample
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/configs/vpb.conf.sample?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/configs/vpb.conf.sample (original)
+++ team/jpeeler/chan_dahdi/configs/vpb.conf.sample Thu May 22 15:51:04 2008
@@ -97,7 +97,7 @@
 ;
 ; NOTE that other caller ID standards are supported in Asterisk, but are
 ; not yet active in chan_vpb.  It should be reasonably trivial to add
-; support for the other standards (see the default zapata.conf for a list
+; support for the other standards (see the default dahdi.conf for a list
 ; of them) that Asterisk already handles.
 ;
 callerid=bell

Modified: team/jpeeler/chan_dahdi/configs/zapata.conf.sample
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/configs/zapata.conf.sample?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/configs/zapata.conf.sample (original)
+++ team/jpeeler/chan_dahdi/configs/zapata.conf.sample Thu May 22 15:51:04 2008
@@ -928,7 +928,7 @@
 
 ; Configuration Sections
 ; ~~~~~~~~~~~~~~~~~~~~~~
-; You can also configure channels in a separate zapata.conf section. In
+; You can also configure channels in a separate dahdi.conf section. In
 ; this case the keyword 'channel' is not used. Instead the keyword
 ; 'zapchan' is used (as in users.conf) - configuration is only processed
 ; in a section where the keyword zapchan is used. It will only be
@@ -948,7 +948,7 @@
 ;
 ; When starting a new section almost all of the configuration values are
 ; copied from their values at the end of the section [channels] in
-; zapata.conf and [general] in users.conf - one section's configuration
+; dahdi.conf and [general] in users.conf - one section's configuration
 ; does not affect another one's.
 ;
 ; Instead of letting common configuration values "slide through" you can 

Modified: team/jpeeler/chan_dahdi/contrib/scripts/autosupport
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/contrib/scripts/autosupport?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/contrib/scripts/autosupport (original)
+++ team/jpeeler/chan_dahdi/contrib/scripts/autosupport Thu May 22 15:51:04 2008
@@ -149,17 +149,18 @@
   echo >> $OUTPUT;
   echo >> $OUTPUT;
 
+  #jpeeler: REVISIT
   echo "------------------" >> $OUTPUT;
   echo "ZAPTEL CONFIG" >> $OUTPUT;
   echo "------------------" >> $OUTPUT;
-  grep -v '^#' /etc/zaptel.conf >> $OUTPUT;
+  grep -v '^#' /etc/dahdi.conf >> $OUTPUT;
   echo >> $OUTPUT;
   echo >> $OUTPUT;
 
   echo "------------------" >> $OUTPUT;
   echo "ZAPATA CONFIG" >> $OUTPUT;
   echo "------------------" >> $OUTPUT;
-  grep -v '^;' /etc/asterisk/zapata.conf >> $OUTPUT;
+  grep -v '^;' /etc/asterisk/dahdi.conf >> $OUTPUT;
   echo >> $OUTPUT;
   echo >> $OUTPUT;
 

Modified: team/jpeeler/chan_dahdi/doc/ss7.txt
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/doc/ss7.txt?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/doc/ss7.txt (original)
+++ team/jpeeler/chan_dahdi/doc/ss7.txt Thu May 22 15:51:04 2008
@@ -31,6 +31,7 @@
 
 These are the commands you would type to install them:
 
+#jpeeler: REVISIT
 `svn co http://svn.digium.com/svn/zaptel/branches/1.4 zaptel-1.4`
 `cd zaptel-1.4`
 `make; make install`

Modified: team/jpeeler/chan_dahdi/doc/tex/ael.tex
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/doc/tex/ael.tex?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/doc/tex/ael.tex (original)
+++ team/jpeeler/chan_dahdi/doc/tex/ael.tex Thu May 22 15:51:04 2008
@@ -47,7 +47,7 @@
 Asterisk acts as a server. Devices involved in telephony, like Zapata
 cards, or Voip phones, all indicate some context that should be
 activated in their behalf. See the config file formats for IAX, SIP,
-zapata.conf, etc. They all help describe a device, and they all
+dahdi.conf, etc. They all help describe a device, and they all
 specify a context to activate when somebody picks up a phone, or a
 call comes in from the phone company, or a voip phone, etc.
 

Modified: team/jpeeler/chan_dahdi/doc/tex/configuration.tex
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/doc/tex/configuration.tex?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/doc/tex/configuration.tex (original)
+++ team/jpeeler/chan_dahdi/doc/tex/configuration.tex Thu May 22 15:51:04 2008
@@ -20,7 +20,7 @@
 \end{verbatim}
 \end{astlisting}
 
-In some files, (e.g. mgcp.conf, zapata.conf and agents.conf), the syntax
+In some files, (e.g. mgcp.conf, dahdi.conf and agents.conf), the syntax
 is a bit different. In these files the syntax is as follows:
 	
 \begin{astlisting}

Modified: team/jpeeler/chan_dahdi/doc/tex/sla.tex
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/doc/tex/sla.tex?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/doc/tex/sla.tex (original)
+++ team/jpeeler/chan_dahdi/doc/tex/sla.tex Thu May 22 15:51:04 2008
@@ -23,7 +23,7 @@
 An SLA system is built up of virtual trunks and stations mapped to real
 Asterisk devices.  The configuration for all of this is done in three
 different files: extensions.conf, sla.conf, and the channel specific
-configuration file such as sip.conf or zapata.conf.
+configuration file such as sip.conf or dahdi.conf.
 
 \subsection{Dialplan}
 
@@ -55,7 +55,7 @@
 An SLA trunk is a mapping between a virtual trunk and a real Asterisk device.
 This device may be an analog FXO line, or something like a SIP trunk.  A trunk
 must be configured in two places.  First, configure the device itself in the
-channel specific configuration file such as zapata.conf or sip.conf.  Once the
+channel specific configuration file such as dahdi.conf or sip.conf.  Once the
 trunk is configured, then map it to an SLA trunk in sla.conf.
 \begin{astlisting}
 \begin{verbatim}
@@ -67,7 +67,7 @@
 
 Be sure to configure the trunk's context to be the same one that is set for the
 "autocontext" option in sla.conf if automatic dialplan configuration is used.
-This would be done in the regular device entry in zapata.conf, sip.conf, etc.
+This would be done in the regular device entry in dahdi.conf, sip.conf, etc.
 Note that the automatic dialplan generation creates the SLATrunk() extension
 at extension 's'.  This is perfect for Zap channels that are FXO trunks, for
 example.  However, it may not be good enough for an IP trunk, since the call
@@ -199,8 +199,8 @@
 \end{astlisting}
 
 With this configuration, the dialplan is generated automatically.  The first
-zap channel should have its context set to "line1" and the second should be
-set to "line2" in zapata.conf.  In sip.conf, station1, station2, and station3
+DAHDI channel should have its context set to "line1" and the second should be
+set to "line2" in dahdi.conf.  In sip.conf, station1, station2, and station3
 should all have their context set to "sla\_stations".
 
 For reference, here is the automatically generated dialplan for this situation:
@@ -244,7 +244,7 @@
 are Zap/1 and Zap/2.  The stations are SIP/station1, SIP/station2, and
 SIP/station3.
 
-In zapata.conf, channel 1 has context=line1 and channel 2 has context=line2.
+In dahdi.conf, channel 1 has context=line1 and channel 2 has context=line2.
 
 In sip.conf, all three stations are configured with context=sla\_stations.
 

Modified: team/jpeeler/chan_dahdi/include/asterisk/doxyref.h
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/include/asterisk/doxyref.h?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================
--- team/jpeeler/chan_dahdi/include/asterisk/doxyref.h (original)
+++ team/jpeeler/chan_dahdi/include/asterisk/doxyref.h Thu May 22 15:51:04 2008
@@ -225,7 +225,7 @@
  * \arg \link Config_sip SIP configuration  \endlink
  * \arg \link Config_mgcp MGCP configuration  \endlink
  * \arg \link Config_rtp RTP configuration  \endlink
- * \arg \link Config_zap Zaptel configuration  \endlink
+ * \arg \link Config_dahdi DAHDI configuration  \endlink
  * \arg \link Config_oss OSS (sound card) configuration  \endlink
  * \arg \link Config_alsa ALSA (sound card) configuration  \endlink
  * \arg \link Config_agent Agent (proxy channel) configuration  \endlink
@@ -339,10 +339,10 @@
  * \verbinclude voicemail.conf.sample
  */
 
-/*! \page Config_zap Zaptel configuration
- * \section zapconf zapata.conf
- * \arg Implemented in \ref chan_zap.c
- * \verbinclude zapata.conf.sample
+/*! \page Config_dahdi DAHDI configuration
+ * \section dahdiconf dahdi.conf
+ * \arg Implemented in \ref chan_dahdi.c
+ * \verbinclude dahdi.conf.sample
  */
 
 /*! \page Config_h323 H.323 channel driver information




More information about the asterisk-commits mailing list
--- team/jpeeler/chan_dahdi/channels/chan_dahdi.c (original)
+++ team/jpeeler/chan_dahdi/channels/chan_dahdi.c Thu May 22 15:51:04 2008
@@ -18,16 +18,16 @@
 
 /*! \file
  *
  * \brief Zaptel Pseudo TDM interface 
  *
  * \author Mark Spencer <markster at digium.com>
  * 
  * Connects to the Zaptel telephony library as well as 
  * libpri. Libpri is optional and needed only if you are
  * going to use ISDN connections.
  *
  * You need to install libraries before you attempt to compile
  * and install the Zaptel channel.
  *
  * \par See also
  * \arg \ref Config_zap
@@ -126,7 +126,7 @@
 static struct ast_jb_conf global_jbconf;
 
 #if !defined(ZT_SIG_EM_E1) || (defined(HAVE_PRI) && !defined(ZT_SIG_HARDHDLC))
 #error "Your Zaptel is too old.  Please update"
 #endif
 
 #ifndef ZT_TONEDETECT
@@ -167,7 +167,7 @@
 /*! \brief Signaling types that need to use MF detection should be placed in this macro */
 #define NEED_MFDETECT(p) (((p)->sig == SIG_FEATDMF) || ((p)->sig == SIG_FEATDMF_TA) || ((p)->sig == SIG_E911) || ((p)->sig == SIG_FGC_CAMA) || ((p)->sig == SIG_FGC_CAMAMF) || ((p)->sig == SIG_FEATB)) 
 
-static const char tdesc[] = "Zapata Telephony Driver"
+static const char tdesc[] = "DAHDI Telephony Driver"
 #ifdef HAVE_PRI
                " w/PRI"
 #endif
@@ -176,7 +176,7 @@
 #endif
 ;
 
-static const char config[] = "zapata.conf";
+static const char config[] = "dahdi.conf";
 
 #define SIG_EM		ZT_SIG_EM
 #define SIG_EMWINK 	(0x0100000 | ZT_SIG_EM)
@@ -715,8 +715,8 @@
 	int muting;
 } *iflist = NULL, *ifend = NULL;
 
 /*! \brief Channel configuration from zapata.conf .
  * This struct is used for parsing the [channels] section of zapata.conf.
  * Generally there is a field here for every possible configuration item.
  *
  * The state of fields is saved along the parsing and whenever a 'channel'
@@ -735,7 +735,7 @@
 	struct zt_ss7 ss7;
 #endif
 	ZT_PARAMS timing;
-	int is_sig_auto; /*!< Use channel signalling from Zaptel? */
+	int is_sig_auto; /*!< Use channel signalling from DAHDI? */
 
 	char smdi_port[SMDI_MAX_FILENAME_LEN];
 };
@@ -6953,7 +6953,7 @@
 								if (p->ringt < p->ringt_base/2)
 									break;
 								/* Increment the ringT counter so we can match it against
-								   values in zapata.conf for distinctive ring */
+								   values in dahdi.conf for distinctive ring */
 								if (++receivedRingT == (sizeof(curRingData) / sizeof(curRingData[0])))
 									break;
 							} else if (i & ZT_IOMUX_READ) {
@@ -6978,7 +6978,7 @@
 							/* this only shows up if you have n of the dring patterns filled in */
 						ast_verb(3, "Detected ring pattern: %d,%d,%d\n",curRingData[0],curRingData[1],curRingData[2]);
 						for (counter = 0; counter < 3; counter++) {
 							/* Check to see if the rings we received match any of the ones in zapata.conf for this
 							channel */
 							distMatches = 0;
 							for (counter1 = 0; counter1 < 3; counter1++) {
@@ -7112,7 +7112,7 @@
 						if (p->ringt < p->ringt_base/2)
 							break;
 						/* Increment the ringT counter so we can match it against
-						   values in zapata.conf for distinctive ring */
+						   values in dahdi.conf for distinctive ring */
 						if (++receivedRingT == (sizeof(curRingData) / sizeof(curRingData[0])))
 							break;
 					} else if (i & ZT_IOMUX_READ) {
@@ -7173,7 +7173,7 @@
 							if (p->ringt < p->ringt_base/2)
 								break;
 							/* Increment the ringT counter so we can match it against
-							   values in zapata.conf for distinctive ring */
+							   values in dahdi.conf for distinctive ring */
 							if (++receivedRingT == (sizeof(curRingData) / sizeof(curRingData[0])))
 								break;
 						} else if (i & ZT_IOMUX_READ) {
@@ -7201,7 +7201,7 @@
 					ast_verb(3, "Detected ring pattern: %d,%d,%d\n",curRingData[0],curRingData[1],curRingData[2]);
 
 					for (counter = 0; counter < 3; counter++) {
 						/* Check to see if the rings we received match any of the ones in zapata.conf for this
 						channel */
 							/* this only shows up if you have n of the dring patterns filled in */
 						ast_verb(3, "Checking %d,%d,%d\n",
@@ -8066,7 +8066,7 @@
 #endif /* HAVE_SS7 */
 
 /* converts a Zaptel sigtype to signalling as can be configured from
- * zapata.conf.
+ * dahdi.conf.
  * While both have basically the same values, this will later be the
  * place to add filters and sanity checks
  */
@@ -11786,7 +11786,7 @@
 		e->usage = 
 			"Usage: zap restart\n"
 			"	Restarts the Zaptel channels: destroys them all and then\n"
-			"	re-reads them from zapata.conf.\n"
+			"	re-reads them from dahdi.conf.\n"
 			"	Note that this will STOP any running CALL on Zaptel channels.\n"
 			"";
 		return NULL;
@@ -14180,22 +14180,22 @@
 						while (c && (i < NUM_DCHANS)) {
 							dchannels[i] = atoi(c + 1);
 							if (dchannels[i] < 0) {
-								ast_log(LOG_WARNING, "D-channel for trunk group %d must be a postiive number at line %d of zapata.conf\n", trunkgroup, v->lineno);
+								ast_log(LOG_WARNING, "D-channel for trunk group %d must be a postiive number at line %d of dahdi.conf\n", trunkgroup, v->lineno);
 							} else
 								i++;
 							c = strchr(c + 1, ',');
 						}
 						if (i) {
 							if (pri_create_trunkgroup(trunkgroup, dchannels)) {
-								ast_log(LOG_WARNING, "Unable to create trunk group %d with Primary D-channel %d at line %d of zapata.conf\n", trunkgroup, dchannels[0], v->lineno);
+								ast_log(LOG_WARNING, "Unable to create trunk group %d with Primary D-channel %d at line %d of dahdi.conf\n", trunkgroup, dchannels[0], v->lineno);
 						} else
 								ast_verb(2, "Created trunk group %d with Primary D-channel %d and %d backup%s\n", trunkgroup, dchannels[0], i - 1, (i == 1) ? "" : "s");
 						} else
-							ast_log(LOG_WARNING, "Trunk group %d lacks any valid D-channels at line %d of zapata.conf\n", trunkgroup, v->lineno);
+							ast_log(LOG_WARNING, "Trunk group %d lacks any valid D-channels at line %d of dahdi.conf\n", trunkgroup, v->lineno);
 					} else
-						ast_log(LOG_WARNING, "Trunk group %d lacks a primary D-channel at line %d of zapata.conf\n", trunkgroup, v->lineno);
+						ast_log(LOG_WARNING, "Trunk group %d lacks a primary D-channel at line %d of dahdi.conf\n", trunkgroup, v->lineno);
 				} else
-					ast_log(LOG_WARNING, "Trunk group identifier must be a positive integer at line %d of zapata.conf\n", v->lineno);
+					ast_log(LOG_WARNING, "Trunk group identifier must be a positive integer at line %d of dahdi.conf\n", v->lineno);
 			} else if (!strcasecmp(v->name, "spanmap")) {
 				spanno = atoi(v->value);
 				if (spanno > 0) {
@@ -14212,13 +14212,13 @@
 							} else
 									ast_verb(2, "Mapped span %d to trunk group %d (logical span %d)\n", spanno, trunkgroup, logicalspan);
 							} else
-								ast_log(LOG_WARNING, "Logical span must be a postive number, or '0' (for unspecified) at line %d of zapata.conf\n", v->lineno);
+								ast_log(LOG_WARNING, "Logical span must be a postive number, or '0' (for unspecified) at line %d of dahdi.conf\n", v->lineno);
 						} else
-							ast_log(LOG_WARNING, "Trunk group must be a postive number at line %d of zapata.conf\n", v->lineno);
+							ast_log(LOG_WARNING, "Trunk group must be a postive number at line %d of dahdi.conf\n", v->lineno);
 					} else
-						ast_log(LOG_WARNING, "Missing trunk group for span map at line %d of zapata.conf\n", v->lineno);
+						ast_log(LOG_WARNING, "Missing trunk group for span map at line %d of dahdi.conf\n", v->lineno);
 				} else
-					ast_log(LOG_WARNING, "Span number must be a postive integer at line %d of zapata.conf\n", v->lineno);
+					ast_log(LOG_WARNING, "Span number must be a postive integer at line %d of dahdi.conf\n", v->lineno);
 			} else {
 				ast_log(LOG_NOTICE, "Ignoring unknown keyword '%s' in trunkgroups\n", v->name);
 			}
@@ -14242,7 +14242,7 @@
 		return res;
 	}
 
 	/* Now get configuration from all normal sections in zapata.conf: */
 	for (cat = ast_category_browse(cfg, NULL); cat ; cat = ast_category_browse(cfg, cat)) {
 		/* [channels] and [trunkgroups] are used. Let's also reserve
 		 * [globals] and [general] for future use
@@ -18,16 +18,16 @@
 /*! \file
  *
- * \brief Zaptel Pseudo TDM interface 
+ * \brief DAHDI for Pseudo TDM
  *
  * \author Mark Spencer <markster at digium.com>
@@ -18,16 +18,16 @@
  * \author Mark Spencer <markster at digium.com>
  * 
- * Connects to the Zaptel telephony library as well as 
+ * Connects to the DAHDI telephony library as well as 
  * libpri. Libpri is optional and needed only if you are
  * going to use ISDN connections.
@@ -18,16 +18,16 @@
  *
  * You need to install libraries before you attempt to compile
- * and install the Zaptel channel.
+ * and install the DAHDI channel.
  *
  * \par See also
@@ -126,7 +126,7 @@
 
 #if !defined(ZT_SIG_EM_E1) || (defined(HAVE_PRI) && !defined(ZT_SIG_HARDHDLC))
-#error "Your Zaptel is too old.  Please update"
+#error "Your DAHDI is too old.  Please update"
 #endif
 
@@ -715,8 +715,8 @@
 } *iflist = NULL, *ifend = NULL;
 
-/*! \brief Channel configuration from zapata.conf .
- * This struct is used for parsing the [channels] section of zapata.conf.
+/*! \brief Channel configuration from dahdi.conf .
+ * This struct is used for parsing the [channels] section of dahdi.conf.
  * Generally there is a field here for every possible configuration item.
  *
@@ -6978,7 +6978,7 @@
 						ast_verb(3, "Detected ring pattern: %d,%d,%d\n",curRingData[0],curRingData[1],curRingData[2]);
 						for (counter = 0; counter < 3; counter++) {
-							/* Check to see if the rings we received match any of the ones in zapata.conf for this
+							/* Check to see if the rings we received match any of the ones in dahdi.conf for this
 							channel */
 							distMatches = 0;
@@ -7201,7 +7201,7 @@
 
 					for (counter = 0; counter < 3; counter++) {
-						/* Check to see if the rings we received match any of the ones in zapata.conf for this
+						/* Check to see if the rings we received match any of the ones in dahdi.conf for this
 						channel */
 							/* this only shows up if you have n of the dring patterns filled in */
@@ -14242,7 +14242,7 @@
 	}
 
-	/* Now get configuration from all normal sections in zapata.conf: */
+	/* Now get configuration from all normal sections in dahdi.conf: */
 	for (cat = ast_category_browse(cfg, NULL); cat ; cat = ast_category_browse(cfg, cat)) {
 		/* [channels] and [trunkgroups] are used. Let's also reserve

Modified: team/jpeeler/chan_dahdi/configs/extensions.ael.sample
URL: http://svn.digium.com/view/asterisk/team/jpeeler/chan_dahdi/configs/extensions.ael.sample?view=diff&rev=117982&r1=117981&r2=117982
==============================================================================